import { LaunchOptions } from "./LaunchOptions";
import { PageNotFoundEvent } from "./PageNotFoundEvent";
import { UnhandledRejectionEvent } from "./UnhandledRejectionEvent";
import { ExitMiniProgramOptions } from "./ExitMiniProgramOptions";
import { ExitMiniProgramResult } from "./ExitMiniProgramResult";
export declare class AppAPI {
    /**
     * 获取小程序本次启动的参数。
     * @version {"kma":"1.26.1","ide":"1.22.0"}
     * @returns 本次启动的参数
     * @example
     * ```javascript
     * const options = ks.getEnterOptionsSync();
     * console.log(options);
     *
     * ```
     *
     */
    getEnterOptionsSync(): LaunchOptions;
    /**
     * 获取小程序启动的参数。
     * @version {"kma":"1.26.1","ide":"1.22.0"}
     * @returns 启动的参数
     * @example
     * ```javascript
     * const options = ks.getLaunchOptionsSync();
     * console.log(options);
     *
     * ```
     *
     */
    getLaunchOptionsSync(): LaunchOptions;
    /**
     * 监听小程序出错事件。
     * @param callback 小程序出错事件的回调函数
     *
     * @example
     * ```javascript
     * ks.onError((error) => {
     *     console.log(error);
     * });
     *
     * ```
     *
     */
    onError(callback: (error: Error) => void): void;
    /**
     * 取消监听小程序出错事件。不传入 `callback` 则取消所有监听。
     * @param callback 小程序出错事件的回调函数
     *
     * @example
     * ```javascript
     * function handlePageError(e) {
     *     console.log('page error', e);
     * }
     *
     * Page({
     *     onLoad: function () {
     *         ks.onError(handlePageError);
     *     },
     *     onHide: function () {
     *         // 取消传入的错误监听函数
     *         ks.offError(handlePageError);
     *         // 取消所有的错误监听函数
     *         ks.offError();
     *     },
     * });
     *
     * ```
     *
     */
    offError(callback?: (error: Error) => void): void;
    /**
     * 监听小程序要打开的页面不存在事件。
     * @param callback 小程序要打开的页面不存在事件的回调函数
     *
     * @example
     * ```javascript
     * ks.onPageNotFound((res) => {
     *     console.log('错误路径：', res.path);
     *     ks.redirectTo({
     *         url: 'path/to/page',
     *     });
     * });
     *
     * ```
     *
     */
    onPageNotFound(callback: (event: PageNotFoundEvent) => void): void;
    /**
     * 取消监听小程序要打开的页面不存在事件。不传入 `callback` 则取消所有监听。
     * @param callback 小程序要打开的页面不存在事件的回调函数
     */
    offPageNotFound(callback?: (event: PageNotFoundEvent) => void): void;
    /**
     * 监听小程序路由切换事件。
     * @param callback 小程序路由切换事件的回调函数
     * @alpha
     *
     * @example
     * ```javascript
     * ks.onAppRoute((res) => {
     *     console.log('小程序路由切换', res);
     * });
     *
     * ```
     *
     */
    onAppRoute(callback: (options: LaunchOptions) => void): void;
    /**
     * 监听小程序切前台事件。
     * @param callback 小程序切前台事件的回调函数
     *
     * @example
     * ```javascript
     * ks.onAppShow((event) => {
     *     console.log('小程序切前台', event);
     * });
     *
     * ```
     *
     */
    onAppShow(callback: (options: LaunchOptions) => void): void;
    /**
     * 取消监听小程序切前台事件。不传入 `callback` 则取消所有监听。
     * @param callback 小程序切前台事件的回调函数
     */
    offAppShow(callback?: (options: LaunchOptions) => void): void;
    /**
     * 监听小程序切后台事件。
     * @param callback 小程序切后台事件的回调函数
     *
     * @example
     * ```javascript
     * ks.onAppHide(() => {
     *     console.log('小程序切后台');
     * });
     *
     * ```
     *
     */
    onAppHide(callback: () => void): void;
    /**
     * 取消监听小程序切后台事件。不传入 `callback` 则取消所有监听。
     * @param callback 小程序切后台事件的回调函数
     */
    offAppHide(callback?: () => void): void;
    /**
     * 监听 `Promise` 被 reject 后未处理事件。
     * @param callback `Promise` 被 reject 后未处理事件的回调函数
     *
     * @example
     * ```javascript
     * ks.onUnhandledRejection((e) => {
     *     console.log(e.promise);
     *     console.log(e.reason);
     * });
     *
     * ```
     *
     */
    onUnhandledRejection(callback: (event: UnhandledRejectionEvent) => void): void;
    /**
     * 取消监听 `Promise` 被 reject 后未处理事件。不传入 `callback` 则取消所有监听。
     * @param callback `Promise` 被 reject 后未处理事件的回调函数
     *
     * @example
     * ```javascript
     * Page({
     *     hanldeUnhandledRejection(e) {
     *         console.log(e.promise);
     *         console.log(e.reason);
     *     },
     *     onLoad() {
     *         ks.onUnhandledRejection(this.hanldeUnhandledRejection);
     *     },
     *     onHide() {
     *         ks.offUnhandledRejection(this.hanldeUnhandledRejection);
     *     },
     * });
     *
     * ```
     *
     */
    offUnhandledRejection(callback?: (event: UnhandledRejectionEvent) => void): void;
    /**
     * 退出当前小程序。必须有点击行为才能调用成功
     * @version {"kma":"1.91.0"}
     * @param options
     * @returns
     */
    exitMiniProgram(options?: ExitMiniProgramOptions): Promise<ExitMiniProgramResult>;
}
