import { PerformanceEntryList } from "../PerformanceEntryList";
import { PerformanceEntry } from "../PerformanceEntry";
import { PerformanceObserver } from "../PerformanceObserver";
/**
 * 用于获取性能数据及创建性能监听器的对象。
 */
export interface Performance {
    /**
     * 创建全局性能事件监听器。
     * @param callback 监听器的回调函数
     * @returns
     *
     * @example
     * ```javascript
     * const performance = ks.getPerformance();
     *
     * // 监听一种类型的性能数据
     * const singleTypeObserver = performance.createObserver((entryList) => {
     *     entryList.getEntries().forEach(({ name, startTime, path, entryType }) => {
     *         console.log(entryType); // 'paint'
     *         console.log(name); // first-paint or first-contentful-paint or  largest-contentful-paint
     *     });
     * });
     *
     * singleTypeObserver.observe({
     *     type: 'paint',
     *     buffered: true,
     * });
     *
     * singleTypeObserver.disconnect();
     *
     * // 监听多种类型的性能数据
     * const multiTypeObserver = performance.createObserver((entryList) => {
     *     entryList
     *         .getEntriesByType('navigation')
     *         .forEach(({ name, path, startTime }) => {
     *             // 收集性能数据
     *         });
     * });
     *
     * multiTypeObserver.observe({
     *     entryTypes: ['navigation', 'mark'],
     * });
     *
     * multiTypeObserver.disconnect();
     *
     * ```
     *
     */
    createObserver(callback: (list: PerformanceEntryList) => void): PerformanceObserver;
    /**
     * 设置性能数据缓冲区大小， 默认缓冲 30 条性能数据。
     * @param size 缓冲区大小
     *
     * @example
     * ```javascript
     * const performance = ks.getPerformance();
     * performance.setBufferSize(20);
     *
     * ```
     *
     */
    setBufferSize(size: number): void;
    /**
     * 获取当前性能数据缓冲区中的所有性能数据。
     * @returns
     *
     * @example
     * ```javascript
     * const performance = ks.getPerformance();
     * const entries = performance.getEntries();
     *
     * ```
     *
     */
    getEntries(): PerformanceEntry[];
    /**
     * 获取当前性能数据缓冲区中所有名称为 `name` 且类型为 `entryType` 的性能数据。
     * @param name 指定性能数据的名称
     * @param entryType 指定性能数据的类型
     * @returns
     *
     * @example
     * ```javascript
     * const performance = ks.getPerformance();
     *
     * const fpEntries = performance.getEntriesByName('first-paint', 'paint');
     * // or
     * const entries = performance.getEntriesByName('name');
     *
     * ```
     *
     */
    getEntriesByName(name: string, entryType?: string): PerformanceEntry[];
    /**
     * 获取当前性能数据缓冲区中所有类型为 `entryType` 的性能数据。
     * @param entryType 指定性能数据的类型
     * @returns
     *
     * @example
     * ```javascript
     * const performance = ks.getPerformance();
     * const navigationEntries = performance.getEntriesByType('navigation');
     *
     * ```
     *
     */
    getEntriesByType(entryType: string): PerformanceEntry[];
    /**
     * 在性能数据缓冲区中使用给定名称添加一个 name 为 `name` 的性能数据。
     * @param name 性能数据名称
     *
     * @example
     * ```javascript
     * const performance = ks.getPerformance();
     *
     * performance.mark('custom');
     *
     * const customEntries = performance.getEntriesByName('custom', 'mark');
     *
     * ```
     *
     */
    mark(name: string): PerformanceEntry;
    /**
     * 清空性能数据缓冲区中 name 为 `name` 的自定义性能数据。若不指定 name，清空所有自定义性能数据。
     * @param name 期望清除的自定义性能数据的名称
     *
     * @example
     * ```javascript
     * const performance = ks.getPerformance();
     *
     * performance.mark('custom');
     * performance.mark('custom');
     *
     * performance.clearMarks('custom');
     *
     * const customEntries = performance.getEntriesByName('custom', 'mark');
     *
     * console.log(customEntries.length === 0); // true
     *
     * ```
     *
     */
    clearMarks(name?: string): void;
}
