import { DisableUserScreenRecordOptions } from "./DisableUserScreenRecordOptions";
import { EnableUserScreenRecordOptions } from "./EnableUserScreenRecordOptions";
import { GetScreenBrightnessOptions } from "./GetScreenBrightnessOptions";
import { GetScreenBrightnessResult } from "./GetScreenBrightnessResult";
import { SetKeepScreenOnOptions } from "./SetKeepScreenOnOptions";
import { SetScreenBrightnessOptions } from "./SetScreenBrightnessOptions";
import { UserScreenRecordEvent } from "./UserScreenRecordEvent";
export declare class ScreenAPI {
    /**
     * 设置屏幕常亮状态。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.setKeepScreenOn({
     *     keepScreenOn: true,
     * });
     *
     * ```
     *
     */
    setKeepScreenOn(options: SetKeepScreenOnOptions): Promise<void>;
    /**
     * 获取屏幕亮度。
     * @param options
     * @returns
     * @example
     * ```javascript
     * const { value } = await ks.getScreenBrightness();
     *
     * ```
     *
     */
    getScreenBrightness(options?: GetScreenBrightnessOptions): Promise<GetScreenBrightnessResult>;
    /**
     * 设置屏幕亮度。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.setScreenBrightness({
     *     value: 100,
     * });
     *
     * ```
     *
     */
    setScreenBrightness(options: SetScreenBrightnessOptions): Promise<void>;
    /**
     * 监听用户主动截屏事件。
     * @param callback 用户主动截屏事件的回调函数
     *
     * @example
     * ```javascript
     * ks.onUserCaptureScreen(() => {
     *     console.log('用户截屏了');
     * });
     *
     * ```
     *
     */
    onUserCaptureScreen(callback: () => void): void;
    /**
     * 取消监听用户主动截屏事件。不传入 `callback` 则取消所有监听。
     * @param callback 用户主动截屏事件的回调函数
     *
     * @example
     * ```javascript
     * ks.offUserCaptureScreen();
     *
     * ```
     *
     */
    offUserCaptureScreen(callback?: () => void): void;
    /**
     * 禁止用户录屏。（仅在 Android 上生效）
     *
     * 1. 实现效果：调用此方法后，在调用 [ks.enableUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.enableUserScreenRecord.html) 恢复录屏能力前，用户录制所得视频为黑屏。
     *
     * 2. 如需在 iOS 系统实现/取消禁止录屏请查看 [ks.onUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.onUserScreenRecord.html) 和 [ks.offUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.offUserScreenRecord.html)。
    * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.disableUserScreenRecord({
     *     success() {
     *         // 防录屏功能开启成功
     *     },
     * });
     *
     * ```
     *
     */
    disableUserScreenRecord(options?: DisableUserScreenRecordOptions): Promise<void>;
    /**
     * 允许用户录屏。（仅在 Android 上生效）
     *
     * 1. 如需禁止录屏请查看 [ks.disableUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.disableUserScreenRecord.html)。
     *
     * 2. 如需在 iOS 系统实现/取消禁止录屏请查看 [ks.onUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.onUserScreenRecord.html) 和 [ks.offUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.offUserScreenRecord.html)。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * ks.enableUserScreenRecord({
     *     success() {
     *         // 关闭防录屏功能成功
     *     },
     * });
     *
     * ```
     *
     */
    enableUserScreenRecord(options?: EnableUserScreenRecordOptions): Promise<void>;
    /**
     * 监听用户主动录屏事件。（仅在 iOS11.0 及以上生效）
     *
     * 1. ***TIP:*** 建议在需要禁止录屏的页面的 `onShow` 调用此方法开启监听， 在页面的 `onHide` 调用 [ks.offUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.offUserScreenRecord.html) 取消监听。
     *
     * 2. 如需在 Android 系统实现/取消禁止录屏请查看 [ks.disableUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.disableUserScreenRecord.html) 和 [ks.enableUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.enableUserScreenRecord.html)。
     * @param callback 监听用户主动录屏事件的回调函数
     * @returns
     *
     * @example
     * ```javascript
     * Page({
     *     disableScreenRecord() {
     *         ks.showToast({
     *             title: '禁止录屏',
     *         });
     *     },
     *     onShow() {
     *         ks.onUserScreenRecord(this.disableScreenRecord);
     *     },
     *     onHide() {
     *         ks.offUserScreenRecord(this.disableScreenRecord);
     *     },
     * });
     *
     * ```
     *
     */
    onUserScreenRecord(callback: (event: UserScreenRecordEvent) => void): void;
    /**
     * 取消监听用户主动录屏事件。不传入 `callback` 则取消所有监听。（仅在 iOS11.0 及以上生效）
     *
     * 1. 如需开启监听请使用 [ks.onUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.onUserScreenRecord.html)。
     *
     * 2. 如需在 Android 系统实现/取消禁止录屏请查看 [ks.disableUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.disableUserScreenRecord.html) 和 [ks.enableUserScreenRecord](https://open.kuaishou.com/docs/develop/api-next/device/screen/ks.enableUserScreenRecord.html)。
     *
     * @param callback 监听用户主动录屏事件的回调函数
     * @returns
     *
     * @example
     * ```javascript
     * Page({
     *     disableScreenRecord() {
     *         ks.showToast({
     *             title: '禁止录屏',
     *         });
     *     },
     *     onShow() {
     *         ks.onUserScreenRecord(this.disableScreenRecord);
     *     },
     *     onHide() {
     *         ks.offUserScreenRecord(this.disableScreenRecord);
     *     },
     * });
     *
     * ```
     *
     */
    offUserScreenRecord(callback?: (event: UserScreenRecordEvent) => void): void;
}
