import { FileSystemManager, GetFileInfoOptions, GetSavedFileListOptions, GetSavedFileListResult, RemoveSavedFileOptions, SaveFileOptions, SaveFileResult } from "./FileSystemManager";
import { GetSavedFileInfoOptions } from "./GetSavedFileInfoOptions";
import { OpenDocumentOptions } from "./OpenDocumentOptions";
import { SavedFileInfo } from "./FileSystemManager/SavedFileInfo";
import { GetFileInfo } from "./FileSystemManager/GetFileInfo";
import type { CommonFileResult } from "./FileSystemManager/CommonFileResult";
export declare class FileAPI {
    /**
     * 获取文件信息。
     * @param options
     * @returns
     * @alpha
     *
     * @example
     * ```javascript
     * const fileInfo = await ks.getFileInfo({
     *     filePath: 'path/to/file',
     * });
     *
     * ```
     *
     */
    getFileInfo(options: GetFileInfoOptions): Promise<GetFileInfo>;
    /**
     * 获取全局唯一的文件管理器。
     * @returns 文件管理器
     * @alpha
     *
     * @example
     * ```javascript
     * const fileSystemManager = ks.getFileSystemManager();
     *
     * ```
     *
     */
    getFileSystemManager(): FileSystemManager;
    /**
     * 获取已保存的本地文件信息。
     * @param options
     * @returns
     * @alpha
     *
     * @example
     * ```javascript
     * const savedFileInfo = await ks.getSavedFileInfo({
     *     filePath: 'path/to/saved/file',
     * });
     *
     * ```
     *
     */
    getSavedFileInfo(options: GetSavedFileInfoOptions): Promise<SavedFileInfo>;
    /**
     * 获取已保存的本地文件列表。
     * @param options
     * @returns
     * @alpha
     *
     * @example
     * ```javascript
     * const { fileList } = await ks.getSavedFileList();
     *
     * ```
     *
     */
    getSavedFileList(options?: GetSavedFileListOptions): Promise<GetSavedFileListResult>;
    /**
     * 在新页面中打开文档。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.openDocument({
     *     filePath: 'path/to/document',
     * });
     *
     * ```
     *
     */
    openDocument(options: OpenDocumentOptions): Promise<void>;
    /**
     * 删除已保存的本地文件。
     * @param options
     * @returns
     * @alpha
     *
     * @example
     * ```javascript
     * await ks.removeSavedFile({
     *     filePath: 'path/to/file',
     * });
     *
     * ```
     *
     */
    removeSavedFile(options: RemoveSavedFileOptions): Promise<CommonFileResult>;
    /**
     * 保存本地临时文件。保存成功后，临时文件将不可用。
     * @param options
     * @returns
     * @alpha
     *
     * @example
     * ```javascript
     * await ks.saveFile({
     *     filePath: 'path/to/save',
     *     tempFilePath: 'path/to/temp/file',
     * });
     *
     * ```
     *
     */
    saveFile(options: SaveFileOptions): Promise<SaveFileResult>;
}
