import { AbstractSelectorQuery } from "../SelectorQuery/AbstractSelectorQuery";
import { NodesRefFields } from "./NodesRefFields";
/**
 * 用于获取 KSML 节点信息的对象。
 */
export interface NodesRef {
    /**
     * 添加节点的布局位置的查询请求。相对于显示区域，以像素为单位。其功能类似于 DOM 的 `getBoundingClientRect`。返回 `NodesRef` 对应的 `SelectorQuery`。
     * @param callback 回调函数，在执行 `SelectorQuery.exec` 方法后，节点信息会在 `callback` 中返回。
     * @returns
     * @example
     * ```javascript
     * ks.createSelectorQuery()
     *     .select('#the-id')
     *     .boundingClientRect(function (rect) {
     *         rect.id; // 节点的ID
     *         rect.dataset; // 节点的dataset
     *         rect.left; // 节点的左边界坐标
     *         rect.right; // 节点的右边界坐标
     *         rect.top; // 节点的上边界坐标
     *         rect.bottom; // 节点的下边界坐标
     *         rect.width; // 节点的宽度
     *         rect.height; // 节点的高度
     *     })
     *     .exec();
     *
     * ks.createSelectorQuery()
     *     .selectAll('.a-class')
     *     .boundingClientRect(function (rects) {
     *         rects.forEach(function (rect) {
     *             rect.id; // 节点的ID
     *             rect.dataset; // 节点的dataset
     *             rect.left; // 节点的左边界坐标
     *             rect.right; // 节点的右边界坐标
     *             rect.top; // 节点的上边界坐标
     *             rect.bottom; // 节点的下边界坐标
     *             rect.width; // 节点的宽度
     *             rect.height; // 节点的高度
     *         });
     *     })
     *     .exec();
     *
     * ```
     *
     */
    boundingClientRect(callback?: (result: Record<string, unknown> | Record<string, unknown>[]) => void): AbstractSelectorQuery;
    /**
     * 添加节点的 `Context` 对象查询请求。目前支持 `CanvasContext` 的获取。
     * @param callback 回调函数。在执行 `SelectorQuery.exec` 方法后，返回节点信息
     * @returns
     * @example
     * ```javascript
     * ks.createSelectorQuery()
     *     .select('.the-video-class')
     *     .context(function (res) {
     *         console.log(res.context); // 节点对应的 Context 对象。如：选中的节点是 <video> 组件，那么此处即返回 VideoContext 对象
     *     })
     *     .exec();
     *
     * ```
     *
     */
    context(callback?: (result: Record<string, unknown> | Record<string, unknown>[]) => void): AbstractSelectorQuery;
    /**
     * 获取节点的相关信息。需要获取的字段在 `fields` 中指定。返回值是 `NodesRef` 对应的 `SelectorQuery`。
     * @param fields
     * @param callback 回调函数
     * @returns
     * @example
     * ```javascript
     * ks.createSelectorQuery()
     *     .select('#the-id')
     *     .fields(
     *         {
     *             dataset: true,
     *             size: true,
     *             scrollOffset: true,
     *             properties: ['scrollX', 'scrollY'],
     *             computedStyle: ['margin', 'backgroundColor'],
     *             context: true,
     *         },
     *         function (res) {
     *             res.dataset; // 节点的dataset
     *             res.width; // 节点的宽度
     *             res.height; // 节点的高度
     *             res.scrollLeft; // 节点的水平滚动位置
     *             res.scrollTop; // 节点的竖直滚动位置
     *             res.scrollX; // 节点 scroll-x 属性的当前值
     *             res.scrollY; // 节点 scroll-y 属性的当前值
     *             // 此处返回指定要返回的样式名
     *             res.margin;
     *             res.backgroundColor;
     *             res.context; // 节点对应的 Context 对象
     *         }
     *     )
     *     .exec();
     *
     * ```
     *
     */
    fields(fields: NodesRefFields, callback?: (result: Record<string, unknown> | Record<string, unknown>[]) => void): AbstractSelectorQuery;
    /**
     * 获取 `Node` 节点实例。目前支持 `Canvas` 的获取。
     * @param callback 回调函数，在执行 `SelectorQuery.exec` 方法后，返回节点信息。
     * @returns
     *
     * @example
     * ```javascript
     * ks.createSelectorQuery()
     *     .select('.canvas')
     *     .node(function (res) {
     *         console.log(res.node); // 节点对应的 Canvas 实例。
     *     })
     *     .exec();
     *
     * ```
     *
     */
    node(callback?: (result: Record<string, unknown> | Record<string, unknown>[]) => void): AbstractSelectorQuery;
    /**
     * 添加节点的滚动位置查询请求。以像素为单位。节点必须是 `scroll-view` 或者 `viewport`，返回 `NodesRef` 对应的 `SelectorQuery`。
     * @param callback 回调函数，在执行 `SelectorQuery.exec` 方法后，节点信息会在 `callback` 中返回。
     * @returns
     * @example
     * ```javascript
     * ks.createSelectorQuery()
     *     .selectViewport()
     *     .scrollOffset(function (res) {
     *         res.id; // 节点的ID
     *         res.dataset; // 节点的dataset
     *         res.scrollLeft; // 节点的水平滚动位置
     *         res.scrollTop; // 节点的竖直滚动位置
     *     })
     *     .exec();
     *
     * ```
     *
     */
    scrollOffset(callback?: (result: Record<string, unknown> | Record<string, unknown>[]) => void): AbstractSelectorQuery;
}
