declare const backgroundAudioProtocols: readonly [
    "http",
    "hls"
];
declare type BackgroundAudioProtocol = typeof backgroundAudioProtocols[number];
/**
 * 背景音频管理器。
 */
export interface BackgroundAudioManager {
    /**
     * 音频资源的地址
     */
    src: string;
    /**
     * 开始播放的时间 (s)
     */
    startTime: number;
    /**
     * 音频标题
     */
    title: string;
    /**
     * 专辑名
     */
    epname: string;
    /**
     * 歌手名
     */
    singer: string;
    /**
     * 封面图 URL
     */
    coverImgUrl: string;
    /**
     * 音频协议
     */
    protocol: BackgroundAudioProtocol;
    /**
     * 播放速度，范围 [0.5, 2.0]
     */
    playbackRate: number;
    /**
     * 当前音频的长度 (s)（只读）
     */
    readonly duration?: number;
    /**
     * 当前音频的播放位置 (s)（只读）
     */
    readonly currentTime?: number;
    /**
     * 是否暂停或停止（只读）
     */
    readonly paused?: boolean;
    /**
     * 音频已缓冲的时间 (s)（只读）
     */
    readonly buffered?: number;
    /**
     * 监听背景音频可播放事件。
     * @param callback 背景音频可播放事件的回调函数
     */
    onCanplay(callback: () => void): void;
    /**
     * 移除 onCanplay 绑定的事件处理函数。
     * @param callback 背景音频可播放事件的回调函数
     */
    offCanplay(callback: () => void): void;
    /**
     * 监听背景音频播放完成事件。
     * @param callback 背景音频播放完成事件的回调函数
     */
    onEnded(callback: () => void): void;
    /**
     * 移除 onEnded 绑定的事件处理函数。
     * @param callback 背景音频播放完成事件的回调函数
     */
    offEnded(callback: () => void): void;
    /**
     * 监听背景音频播放出错事件。
     * @param callback 背景音频播放出错事件的回调函数
     */
    onError(callback: () => void): void;
    /**
     * 移除 onError 绑定的事件处理函数。
     * @param callback 背景音频播放出错事件的回调函数
     */
    offError(callback: () => void): void;
    /**
     * 监听用户在系统音乐播放面板点击下一首事件。（仅在 iOS 上生效）
     * @param callback 用户在系统音乐播放面板点击下一首事件的回调函数
     */
    onNext(callback: () => void): void;
    /**
     * 移除 onNext 绑定的事件处理函数。
     * @param callback 用户在系统音乐播放面板点击下一首事件的回调函数
     */
    offNext(callback: () => void): void;
    /**
     * 监听背景音频暂停播放事件。
     * @param callback 背景音频暂停播放事件的回调函数
     */
    onPause(callback: () => void): void;
    /**
     * 移除 onPause 绑定的事件处理函数。
     * @param callback 背景音频暂停播放事件的回调函数
     */
    offPause(callback: () => void): void;
    /**
     * 监听背景音频开始播放事件。
     * @param callback 背景音频开始播放事件的回调函数
     */
    onPlay(callback: () => void): void;
    /**
     * 移除 onPlay 绑定的事件处理函数。
     * @param callback 背景音频开始播放事件的回调函数
     */
    offPlay(callback: () => void): void;
    /**
     * 监听用户在系统音乐播放面板点击上一首事件。（仅在 iOS 上生效）
     * @param callback 用户在系统音乐播放面板点击上一首事件的回调函数
     */
    onPrev(callback: () => void): void;
    /**
     * 移除 onPrev 绑定的事件处理函数。
     * @param callback 用户在系统音乐播放面板点击上一首事件的回调函数
     */
    offPrev(callback: () => void): void;
    /**
     * 监听背景音频已跳转到指定位置事件。
     * @param callback 背景音频已跳转到指定位置事件的回调函数
     */
    onSeeked(callback: () => void): void;
    /**
     * 移除 onSeeked 绑定的事件处理函数
     * @param callback 背景音频已跳转到指定位置事件的回调函数
     */
    offSeeked(callback: () => void): void;
    /**
     * 监听背景音频开始跳转到指定位置事件。
     * @param callback 背景音频开始跳转到指定位置事件的回调函数
     */
    onSeeking(callback: () => void): void;
    /**
     * 移除 onSeeking 绑定的事件处理函数
     * @param callback 背景音频开始跳转到指定位置事件的回调函数
     */
    offSeeking(callback: () => void): void;
    /**
     * 监听背景音频停止播放事件。
     * @param callback 背景音频停止播放事件的回调函数
     */
    onStop(callback: () => void): void;
    /**
     * 移除 onStop 绑定的事件处理函数
     * @param callback 背景音频停止播放事件的回调函数
     */
    offStop(callback: () => void): void;
    /**
     * 监听背景音频播放进度更新事件（仅在小程序前台生效）。
     * @param callback 背景音频播放进度更新事件的回调函数
     */
    onTimeUpdate(callback: () => void): void;
    /**
     * 移除 onTimeUpdate 绑定的事件处理函数
     * @param callback 背景音频播放进度更新事件的回调函数
     */
    offTimeUpdate(callback: () => void): void;
    /**
     * 监听背景音频加载中事件。
     * @param callback 背景音频加载中事件的回调函数
     */
    onWaiting(callback: () => void): void;
    /**
     * 移除 onWaiting 绑定的事件处理函数
     * @param callback 背景音频加载中事件的回调函数
     */
    offWaiting(callback: () => void): void;
    /**
     * 暂停播放背景音频。
     */
    pause(): void;
    /**
     * 开始播放背景音频。
     */
    play(): void;
    /**
     * 跳转到背景音频的指定位置。
     * @param currentTime 跳转位置 (s)
     */
    seek(currentTime: number): void;
    /**
     * 停止播放背景音频。
     */
    stop(): void;
}
export {};
