import type { Mixins } from "../../common";
import { ChooseVideoOptions } from "./ChooseVideoOptions";
import { ChooseVideoResult } from "./ChooseVideoResult";
import { SaveVideoToPhotosAlbumOptions } from "./SaveVideoToPhotosAlbumOptions";
import { VideoContext } from "./VideoContext";
import { VideoStorageAPI } from "./VideoStorage";
import { PreloadVideoTask } from "./PreloadVideoTask";
import { ChooseMediaOptions } from "./ChooseMediaOptions";
import { ChooseMediaResult } from "./ChooseMediaResult";
import { PreloadVideoOptions } from "./PreloadVideoOptions";
declare const VideoAPIs: readonly [
    typeof VideoStorageAPI
];
export declare class VideoAPI {
    /**
     * 创建视频上下文对象。
     * @version {"kma":"1.26.1","ide":"1.22.0"}
     * @param id `<video>` 组件的 `id` 属性
     * @returns 视频上下文对象
     * @example
     * ```javascript
     * Page({
     *     onReady() {
     *         const ctx = ks.createVideoContext('myVideo');
     *         ctx.play();
     *     },
     * });
     *
     * ```
     *
     */
    createVideoContext(id: string): VideoContext;
    /**
     * 从本地相册选择视频，或使用相机拍摄视频。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * const { tempFilePath } = await ks.chooseVideo({
     *     sourceType: ['album', 'camera'],
     *     maxDuration: 60,
     *     camera: 'back',
     * });
     *
     * ```
     *
     */
    chooseVideo(options?: ChooseVideoOptions): Promise<ChooseVideoResult>;
    /**
     * 创建视频预加载任务。预加载成功后的视频资源生效区间为整个小程序。
     * @version {"kma":"1.91.0"}
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * const preloadVideoTask = ks.preloadVideo({
     *     src: 'http://static.yximgs.com/udata/pkg/fe/kwai_video.a7616d99.mp4',
     *     size: 819200,
     *     success: () => {
     *         console.log('预加载成功');
     *     },
     *     fail: () => {
     *         console.log('预加载失败');
     *     },
     * });
     *
     * ```
     *
     */
    preloadVideo(options: PreloadVideoOptions): PreloadVideoTask;
    /**
     * 拍摄或从手机相册中选择图片或视频。
     * @version {"kma":"1.90.0"}
     * @param options
     * @returns
     * @example
     * ```javascript
     * const { tempFiles } = await ks.chooseMedia({
     *     sourceType: ['album', 'camera'],
     *     maxDuration: 60,
     *     camera: 'back',
     * });
     *
     * ```
     *
     */
    chooseMedia(options?: ChooseMediaOptions): Promise<ChooseMediaResult>;
    /**
     * 保存视频到系统相册。调用前需要 [用户授权](https://open.kuaishou.com/docs/develop/api-next/open/authorize/ks.authorize) `scope.writePhotosAlbum`。
     * @param options
     * @returns
     *
     * @example
     * ```javascript
     * await ks.saveVideoToPhotosAlbum({
     *     filePath: 'path/to/image',
     * });
     *
     * ```
     *
     */
    saveVideoToPhotosAlbum(options: SaveVideoToPhotosAlbumOptions): Promise<void>;
}
export interface VideoAPI extends Mixins<typeof VideoAPIs> {
}
export {};
