import { CheckSessionOptions } from "./CheckSessionOptions";
import { LoginOptions } from "./LoginOptions";
import { LoginResult } from "./LoginResult";
export declare class LoginAPI {
    /**
     * 检查登录态是否有效。
     * 通过 `ks.login` 接口获取的用户登录态具有一定的时效性，与用户最近是否使用小程序有关，具体时效逻辑由快手维护。登录态过期后开发者可以调用 `ks.login` 获取新的用户登录态。
     *
     * @version {"kma":"1.26.1","ide":"1.22.0"}
     * @param options
     * @returns
     *
     * @errinfo [{"errMsg":"session expired","errDesc":"会话已过期"},{"errMsg":"Invalid app","errDesc":"应用不存在"},{"errMsg":"beyond token/app/authorized scope","errDesc":"请求被拒绝，可能是无效token或应用/用户不允许访问该接口"},{"errMsg":"not exist user","errDesc":"用户信息不存在"},{"errMsg":"invalid scope","errDesc":"请求授权的scope错误"}]
     *
     *
     * @example
     * ```javascript
     * ks.checkSession({
     *     success() {
     *         // session_key 未过期，并且在本生命周期一直有效
     *     },
     *     fail() {
     *         // session_key 已经失效，需要重新执行登录流程
     *         ks.login(); // 重新登录
     *     },
     * });
     *
     * ```
     *
     */
    checkSession(options?: CheckSessionOptions): Promise<void>;
    /**
     * 获取用户登录凭证，进而获取用户登录态信息。详见 [登录](https://open.kuaishou.com/docs/develop/server/code2Session)。
     * @version {"kma":"1.26.1","ide":"1.22.0"}
     * @param options
     * @returns
     * @errinfo [{"errMsg":"Invalid appId","errDesc":"应用不存在"},{"errMsg":"appType not allowed/userId is not app member","errDesc":"请求被拒绝，可能是无效token或应用/用户不允许访问该接口"}]
     * @example
     * ```javascript
     * ks.login({
     *     success(res) {
     *         if (res.code) {
     *             // 发起网络请求
     *             ks.request({
     *                 url: 'https://test.com/onLogin',
     *                 data: {
     *                     code: res.code,
     *                 },
     *             });
     *         } else {
     *             // 登录失败
     *         }
     *     },
     * });
     *
     * ```
     *
     */
    login(options?: LoginOptions): Promise<LoginResult>;
}
