import { AnimationOptions } from "./AnimationOptions";
import { ExportedAnimation } from "./ExportedAnimation";
/**
 * 动画对象。
 */
export interface Animation {
    /**
     * 表示一组动画完成。可以在一组动画中调用任意多个动画方法，一组动画中的所有动画会同时开始，一组动画完成后才会进行下一组动画。
     * @param options
     * @returns animation
     * @alpha
     */
    step(options?: AnimationOptions): this;
    /**
     * 导出动画队列。`export` **方法每次调用后会清掉之前的动画操作**。
     * @returns animationData
     * @alpha
     */
    export(): ExportedAnimation;
    /**
     * 从原点顺时针旋转一个角度。
     * @param angle 旋转的角度。范围 [-180, 180]
     * @returns
     * @alpha
     */
    rotate(angle: number): Animation;
    /**
     * 从 X 轴顺时针旋转一个角度。
     * @param angle 旋转的角度。范围 [-180, 180]
     * @returns
     * @alpha
     */
    rotateX(angle: number): Animation;
    /**
     * 缩放。
     * @param sx 当仅有 sx 参数时，表示在 X 轴、Y 轴同时缩放 sx 倍数
     * @param sy 在 Y 轴缩放 sy 倍数
     * @returns
     * @alpha
     */
    scale(sx: number, sy?: number): Animation;
    /**
     * 对 X、Y 轴坐标进行倾斜。
     * @param ax 对 X 轴坐标倾斜的角度，范围 [-180, 180]
     * @param ay 对 Y 轴坐标倾斜的角度，范围 [-180, 180]
     * @returns
     * @alpha
     */
    skew(ax: number, ay: number): Animation;
    /**
     * 平移变换。
     * @param tx 当仅有该参数时表示在 X 轴偏移 tx (px)
     * @param ty 在 Y 轴平移的距离，单位为 px
     * @returns
     * @alpha
     */
    translate(tx: number, ty: number): Animation;
    /**
     * 对 XYZ 坐标进行平移变换。
     * @param tx 在 X 轴平移的距离，单位为 px
     * @param ty 在 Y 轴平移的距离，单位为 px
     * @param tz 在 Z 轴平移的距离，单位为 px
     * @returns
     * @alpha
     */
    translate3d(tx: number, ty: number, tz: number): Animation;
    /**
     * 对 X 轴平移。
     * @param translation 在 X 轴平移的距离，单位为 px
     * @returns
     * @alpha
     */
    translateX(translation: number): Animation;
    /**
     * 对 Y 轴平移。
     * @param translation 在 Y 轴平移的距离，单位为 px
     * @returns
     * @alpha
     */
    translateY(translation: number): Animation;
    /**
     * 设置透明度。
     * @param value 透明度，范围 0-1
     * @returns
     * @alpha
     */
    opacity(value: number): Animation;
    /**
     * 设置背景色。
     * @param value 颜色值
     * @returns
     * @alpha
     */
    backgroundColor(value: string): Animation;
    /**
     * 设置高度。
     * @param value 长度值，如果传入 number 则默认使用 px，可传入其他自定义单位的长度值
     * @returns
     * @alpha
     */
    height(value: number | string): Animation;
    /**
     * 设置 left 值。
     * @param value 长度值，如果传入 number 则默认使用 px，可传入其他自定义单位的长度值
     * @returns
     * @alpha
     */
    left(value: number | string): Animation;
    /**
     * 设置 top 值。
     * @param value 长度值，如果传入 number 则默认使用 px，可传入其他自定义单位的长度值
     * @returns
     * @alpha
     */
    top(value: number | string): Animation;
    /**
     * 设置 bottom 值。
     * @param value 长度值，如果传入 number 则默认使用 px，可传入其他自定义单位的长度值
     * @returns
     * @alpha
     */
    bottom(value: number | string): Animation;
}
