import type { EventChannel } from "../apis/basic/route/EventChannel";
import type { IntersectionObserver, IntersectionObserverOptions } from "../apis/ksml/IntersectionObserver";
import type { SelectorQuery } from "../apis/ksml/SelectorQuery";
import type { AnyObject, CustomShareContent, PageResizeEvent, PageScrollEvent, PageShareAppMessageEvent, PageTabItemTapEvent } from "./common";
import type { ComponentInstanceType, ComponentOptions } from "./component";
export interface PageLifeCycle {
    /**
     * 生命周期回调—监听页面加载
     *
     * 页面加载时触发。一个页面只会调用一次，可以在 onLoad 的参数中获取打开当前页面路径中的参数。
     * @param query 打开当前页面路径中的参数
     */
    onLoad(query: Record<string, string | undefined>): void;
    /**
     * 生命周期回调—监听页面显示
     *
     * 页面显示/切入前台时触发。
     */
    onShow(): void;
    /** 生命周期回调—监听页面初次渲染完成
     *
     * 页面初次渲染完成时触发。一个页面只会调用一次，代表页面已经准备妥当，可以和视图层进行交互。
     *
     * 注意：对界面内容进行设置的 API 如`ks.setNavigationBarTitle`，请在`onReady`之后进行。
     */
    onReady(): void;
    /**
     * 生命周期回调—监听页面隐藏
     *
     * 页面隐藏/切入后台时触发。 如 `ks.navigateTo` 或底部 `tab` 切换到其他页面，小程序切入后台等。
     */
    onHide(): void;
    /**
     * 生命周期回调—监听页面卸载
     *
     * 页面卸载时触发。如`redirectTo`或`navigateBack`到其他页面时。
     */
    onUnload(): void;
    /**
     * 监听用户下拉动作
     *
     * 监听用户下拉刷新事件。
     * - 需要在`app.json`的`window`选项中或页面配置中开启`enablePullDownRefresh`。
     * - 可以通过`ks.startPullDownRefresh`触发下拉刷新，调用后触发下拉刷新动画，效果与用户手动下拉刷新一致。
     * - 当处理完数据刷新后，`ks.stopPullDownRefresh`可以停止当前页面的下拉刷新。
     */
    onPullDownRefresh(): void;
    /**
     * 页面上拉触底事件的处理函数
     *
     * 监听用户上拉触底事件。
     * - 可以在`app.json`的`window`选项中或页面配置中设置触发距离`onReachBottomDistance`。
     * - 在触发距离内滑动期间，本事件只会被触发一次。
     */
    onReachBottom(): void;
    /**
     * 用户点击右上角转发
     *
     * 监听用户点击页面内转发按钮（`<button>` 组件 `open-type="share"`）或右上角菜单“转发”按钮的行为，并自定义转发内容。
     *
     * **注意：只有定义了此事件处理函数，右上角菜单才会显示“转发”按钮**
     *
     * @return 用于自定义转发内容的对象
     */
    onShareAppMessage(event: PageShareAppMessageEvent): CustomShareContent;
    /**
     *  页面滚动触发事件的处理函数
     *
     * 监听用户滑动页面事件。
     * @param event 页面滚动事件
     */
    onPageScroll(event: PageScrollEvent): void;
    /**
     * 当前是 tab 页时，点击 tab 时触发。
     * @param event tab 点击事件
     */
    onTabItemTap(event: PageTabItemTapEvent): void;
    /**
     * 窗口尺寸改变时触发
     * @param event 窗口尺寸改变事件
     */
    onResize(event: PageResizeEvent): void;
    /**
     * 用于动态上报数据
     *
     * 用于注册业务上报数据。一个页面只会调用一次，可以在 onLoad 的参数中获取打开当前页面路径中的参数。
     * @param query 打开当前页面路径中的参数
     */
    registerMetaData(query: Record<string, string | undefined>): any;
}
interface PageProperties {
    /**
     * 页面的文件路径
     */
    is: string;
    /**
     * 到当前页面的路径
     */
    route: string;
    /**
     * 打开当前页面路径中的参数
     */
    options: Record<string, string>;
}
interface PageMethods {
    /**
     * 获取当前页面的 `eventChannel`， 可与 `ks.navigateTo` 返回结果中的 `eventChannel` 通信。
     * @returns 当前页面的 `eventChannel`
     */
    getOpenerEventChannel(): EventChannel;
    /**
     * 创建并返回一个 `SelectorQuery` 对象实例。在自定义组件或包含自定义组件的页面中使用，用法同 ks.createSelectorQuery。
     * @returns  `SelectorQuery` 对象实例, 用于查询节点信息
     */
    createSelectorQuery(): SelectorQuery;
    /**
     * 创建并返回一个 `IntersectionObserver` 对象实例。在自定义组件或包含自定义组件的页面中使用，用法同 ks.createIntersectionObserver。
     */
    createIntersectionObserver(options: IntersectionObserverOptions): IntersectionObserver;
    /**
     * 使用选择器选择组件实例节点，返回匹配到的第一个组件实例对象。
     * @param selector 选择器
     * @returns 匹配到的第一个组件实例对象
     */
    selectComponent<T extends ComponentOptions<any, any, any> | void>(selector: string): ComponentInstanceType<T> | null;
    /**
     * 使用选择器选择组件实例节点，返回匹配到的全部组件实例对象组成的数组。
     * @param selector 选择器
     * @returns 匹配到的全部组件实例对象组成的数组
     */
    selectAllComponents<T extends ComponentOptions<any, any, any> | void>(selector: string): ComponentInstanceType<T>[];
    /**
     * 获取这个关系所对应的所有关联组件节点。
     * @param relationPath 关联组件的路径
     * @returns 所有关联组件节点数组
     */
    getRelationNodes<T extends ComponentOptions<any, any, any> | void>(relationPath: string): ComponentInstanceType<T>[];
}
export declare type PageInstance<Data extends AnyObject, Custom extends AnyObject> = {
    /**
     * 页面的数据
     */
    data: Data;
    /**
     * 改变页面的数据。
     * @param data 这次要改变的数据
     * @param callback setData引起的界面更新渲染完毕后的回调函数
     */
    setData(data: Partial<Data> & AnyObject, callback?: () => void): void;
} & Partial<PageLifeCycle> & PageMethods & PageProperties & Custom & {
    /**
     * @deprecated
     */
    __wxExparserNodeId__: string;
    /**
     * @deprecated
     */
    __wxWebviewId__: number;
};
export declare type PageOptions<Data extends AnyObject, Custom extends AnyObject> = {
    /**
     * 页面的初始数据
     */
    data?: Data;
} & Partial<PageLifeCycle> & ThisType<PageInstance<Data, Custom>> & Custom;
export declare type PageConstructor = <Data extends AnyObject = {}, Custom extends AnyObject = {}>(options: PageOptions<Data, Custom>) => void | PageOptions<Data, Custom>;
export declare type PageInstanceType<T extends PageOptions<any, any> | void> = T extends PageOptions<infer Data, infer Custom> ? PageInstance<Data, Custom> : never;
export declare type GetCurrentPages = <Data, Custom>() => PageInstance<Data, Custom>[];
export {};
